You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tuscany.apache.org by ke...@apache.org on 2006/10/18 14:25:20 UTC

svn commit: r465232 [2/2] - in /incubator/tuscany/java: sdo/ sdo/distribution/ sdo/distribution/src/ sdo/impl/ sdo/impl/src/main/java/org/apache/tuscany/sdo/ sdo/impl/src/test/resources/ sdo/sample/ sdo/sample/distribution/ sdo/sample/src/main/java/org...

Modified: incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/otherSources/ReadPurchaseOrder.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/otherSources/ReadPurchaseOrder.java?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/otherSources/package.html (original)
+++ incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/otherSources/package.html Wed Oct 18 05:25:18 2006
@@ -23,16 +23,18 @@
 </head>
 <body>
 
-Provides examples from sources other than the specification.  These examples are from whitepapers, 
+Provides examples from sources other than the SDO specification.  These examples are from whitepapers, 
 	or are custom examples designed to show SDO in a more elegant light than the specification.  They 
-	also include basic interactive examples, and usefull scnearios not outlined in the specification.  
+	also include basic interactive examples, and useful scenarios not outlined in the specification.  
 	The user is encouraged to modify and execute these code examples.
 
 <h2>Related Documentation</h2>
 
-For overviews, tutorials, examples, guides, and tool documentation, please see:
+<h2>Related Documentation</h2>
+For overviews, tutorials, examples, guides, and tool documentation, please see
+	
 <ul>
-   <li><a href="http://download.boulder.ibm.com/ibmdl/pub/software/dw/specs/ws-sdo/SDO_Specification_Java_V2.01.pdf">SDO Specification</a></li>
+   <li><a href="http://incubator.apache.org/tuscany/java_sdo_overview.html"> SDO Java Overview</a> section of the Tuscany website.</li>
    <li><a href="http://www-128.ibm.com/developerworks/webservices/library/ws-sdoxmlschema/">Create and read an XML document based on XML Schema</a></li>
 </ul>
 

Modified: incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/overview.html
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/overview.html?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/overview.html (original)
+++ incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/overview.html Wed Oct 18 05:25:18 2006
@@ -3,28 +3,28 @@
 	<title>SDO Sample Overview</title>
 </head>
 <BODY>
-<h1>Tuscany Service Data Object (SDO) Samples Programs</h1>  
+<h1>Tuscany Service Data Object (SDO) Sample Programs</h1>  
 <h2>Overview</h2>
 This sample code is from the <a href="http://incubator.apache.org/tuscany"
  target="_blank"> Apache Tuscany</a> project. The samples were written to help users
 understand and experiment with SDO. They are grouped into three packages according to the source of the example material. Some are based upon example code contained
 within the <a
- href="http://download.boulder.ibm.com/ibmdl/pub/software/dw/specs/ws-sdo/SDO_Specification_Java_V2.01.pdf"
- target="_bank">SDO Specification</a>, and are intended to be read alongside the specification. Others are based upon papers and published material (see the documentation for each sample for the reference to the publication),
-<BR>
-and the third category were simply written 
-	specifically for these samples.<H2>Experimentation</H2>
+ href="http://osoa.org/download/attachments/791/SDO_Specification_Java_V2.01.pdf?version=1"
+ target="_bank">SDO Specification</a>, and are intended to be read alongside the specification. Others are based upon papers and published material
+ (see the documentation for each sample for the reference to the publication),
+ or were simply written specifically for these samples.
+<H2>Experimentation</H2>
 The SDO samples are written to be used in conjunction with the specification and other documents.  However, 
 the most important function that these samples provide is a place to begin experimenting with the SDO API
 and programming model.  Developers are encouraged to extend and experiment with the current set of samples.  
 If a sample is unclear, is missing documentation or a tutorial, or does not cover a desired area ,
 please send feedback to the tuscany mailing lists,
-or better still send us a patch or <BR> join the Tuscany team and contribute back to the
+or better still send us a patch or join the Tuscany team and contribute back to the
 <A href="http://incubator.apache.org/tuscany">project</A>.
   
 
 <h3>Getting Ready to run the Samples</h3>
-The samples depend of the following libraries<UL>
+The samples depend on the following libraries<UL>
 		<LI>The SDO API and the Tuscany SDO Implementation
 		<UL>
 			<LI>sdo-api-{version}.jar - SDO API</LI>
@@ -44,7 +44,7 @@
 			<LI>xsd-{version}.jar - the XML Schema model</LI></UL></LI></UL>
 <P>If you are running these samples from a Tuscany samples distribution you can resolve these dependencies by ensuring that all the jar files in the lib directory of the extracted distribution are on your classpath.<BR>
 <BR>
-If you are running these samples as a result of building Tuscany SDO for Java from a Tuscany source distribution using maven then these dependencies will be resolved by having followed the build insrtuctions.<BR>
+If you are running these samples as a result of building Tuscany SDO for Java from a Tuscany source distribution using maven then these dependencies will be resolved by having followed the build instructions.<BR>
 <BR>To run these samples against the current Tuscany codebase, follow the instructions at <A
 	href="http://incubator.apache.org/tuscany/java_sdo_overview.html">Tuscany SDO Java Overview</A>, which describes how to build Tuscany SDO for Java in an Eclipse SDK environment.</P>
 <H3>Running the Samples</H3>

Modified: incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/package.html
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/package.html?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/package.html (original)
+++ incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/package.html Wed Oct 18 05:25:18 2006
@@ -24,9 +24,10 @@
 <body>
 Provides common constants and a command line java interface for executing samples.
 <h2>Related Documentation</h2>
-
-For overviews, tutorials, examples, guides, and tool documentation, please see:
-
+For overviews, tutorials, examples, guides, and tool documentation, please see the
+<a href="http://incubator.apache.org/tuscany/java_sdo_overview.html"> SDO Java Overview
+</a>
+section of the Tuscany website.	  
 
 </body>
 </html>

Modified: incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/specCodeSnippets/AccessDataObjectUsingValidXPath.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/specCodeSnippets/AccessDataObjectUsingValidXPath.java?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/specCodeSnippets/AccessDataObjectUsingValidXPath.java (original)
+++ incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/specCodeSnippets/AccessDataObjectUsingValidXPath.java Wed Oct 18 05:25:18 2006
@@ -27,7 +27,7 @@
 import commonj.sdo.helper.XSDHelper;
 
 /**
- * Demonstrats accessing a created DataObject's properties using xPath.
+ * Demonstrates accessing a created DataObject's properties using xPath.
  * 
  * This sample is from the <a href="http://incubator.apache.org/tuscany"
  * target="_blank"> Apache Tuscany</a> project. It was written to help users
@@ -41,10 +41,37 @@
  * use unpure xpath expression. This sample attempts to demonstrate a more appropiate
  * subset of xPath operations.<br>
  * <br>
+ * <br>
+ * <br>
  * <b>Usage:</b> <br>
- * Include the following on your classpath :
- * codegen-2.2.0-SNAPSHOT.jar,codegen-ecore-2.2.0-SNAPSHOT.jar,common-2.2.0-SNAPSHOT.jar,ecore-2.2.0-SNAPSHOT.jar,ecore-change-2.2.0-SNAPSHOT.jar,ecore-xmi-2.2.0-SNAPSHOT.jar,sdo-api-SNAPSHOT.jar,tuscany-sdo-impl-SNAPSHOT.jar,xsd-2.2.0-SNAPSHOT.jar,sdo-samples-standAlone-1.0-SNAPSHOT.jar
+ * This sample can easily be run from within Eclipse as a Java Application if tuscany or 
+ * the sample-sdo project is imported into Eclipse as an existing project.
+ * <br><br>
+ * If executing as a standalone application please do the following: 
  * <br>
+ * <UL>
+ * <LI>Include the following jar files on your classpath :
+ * <UL>
+ * <LI>SDO API and Tuscany Implementation
+ * <UL>
+ * <LI>sdo-api-{version}.jar - SDO API
+ * <LI>tuscany-sdo-impl-{version}.jar - Tuscany SDO implementation
+ * </UL>
+ * </LI>
+ * <LI>EMF dependencies. 
+ * <UL>
+ * <LI>emf-common-{version}.jar - some common framework utility and base classes
+ * <LI>emf-ecore-{version}.jar - the EMF core runtime implementation classes (the Ecore metamodel)
+ * <LI>emf-ecore-change-{version}.jar - the EMF change recorder and framework
+ * <LI>emf-ecore-xmi-{version}.jar - EMF's default XML (and XMI) serializer and loader
+ * <LI>xsd-{version}.jar - the XML Schema model
+ * </UL>
+ * </LI>
+ * </UL>
+ * 
+ * These jar files can be obtained from directly from Tuscany and EMF projects or from <a
+ * href="http://wiki.apache.org/ws-data/attachments/Tuscany(2f)TuscanyJava(2f)SDO_Java_Overview/attachments/SDO%20Execution%20Dependencies"
+ * target="_bank">SDO Execution Dependencies </a> </LI>
  * Execute: java
  * org.apache.tuscany.samples.sdo.specCodeSnippets.AccessDataObjectUsingValidXPath
  * 

Modified: incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/specCodeSnippets/UsingXPath.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/specCodeSnippets/UsingXPath.java?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/specCodeSnippets/UsingXPath.java (original)
+++ incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/specCodeSnippets/UsingXPath.java Wed Oct 18 05:25:18 2006
@@ -80,12 +80,12 @@
      * @param purchaseOrder.
      *            DataObject defined by Types in {@link org.apache.tuscany.samples.sdo.SdoSampleConstants#PO_XSD_RESOURCE}
      */
-    public static void accessDataObjectUsingXPath(DataObject purchaseOrder) {
+    public static void accessDataObjectUsingXPath(DataObject purchaseOrder) throws Exception {
         // TODO: use variety of xpath expressions such as items/item[1]
         // TODO: add to junit test cases for test cases above
 
         // xpath expressions for obtaining various items
-        String[] xPathExpressions = { "items/item[1]","items/item[productName=Baby Monitor]" };
+        String[] xPathExpressions = { "items/item[1]","items/item[productName=\"Baby Monitor\"]" };
 
         for (int i = 0; i < xPathExpressions.length; i++) {
             try {
@@ -98,6 +98,7 @@
                 System.out.println("    Part num: " + item.get("partNum"));
             } catch (Exception e) {
                 System.out.println("    Sorry there was an error executing expression " + xPathExpressions[i]);
+                throw e; 
             }
         }
         

Modified: incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/specCodeSnippets/package.html
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/specCodeSnippets/package.html?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/specCodeSnippets/package.html (original)
+++ incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/specCodeSnippets/package.html Wed Oct 18 05:25:18 2006
@@ -23,20 +23,18 @@
 </head>
 <body>
 
-Provides examples containing code snipets located throughout the SDO Specification.  In general these samples attempt to use the
-code and comments contained within the specification but allow a certain degree of flexability extend or improve 
-upon the code snipets where desireable.
+Provides examples containing code snippets located throughout the SDO Specification.  In general these samples attempt to use the
+code and comments contained within the specification but allow a certain degree of flexibility to extend or improve 
+upon the code snippets where desirable.
 	The user is encouraged to modify and execute these code examples.
 
 
 <h2>Related Documentation</h2>
 
-For overviews, tutorials, examples, guides, and tool documentation, please see:
-<ul>
-  <li>
-	<a href="http://download.boulder.ibm.com/ibmdl/pub/software/dw/specs/ws-sdo/SDO_Specification_Java_V2.01.pdf">SDO Specification</a>
-	</li>	  
-</ul>
+For overviews, tutorials, examples, guides, and tool documentation, please see the
+<a href="http://incubator.apache.org/tuscany/java_sdo_overview.html"> SDO Java Overview
+</a>
+section of the Tuscany website.	  
 
 </body>
 </html>

Modified: incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/specExampleSection/package.html
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/specExampleSection/package.html?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/specExampleSection/package.html (original)
+++ incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/specExampleSection/package.html Wed Oct 18 05:25:18 2006
@@ -24,19 +24,16 @@
 <body>
 
 Provides samples from the Examples section of the SDO Specification.  In general these samples attempt to use the
-code and comments contained within the specification, exceptions to this are noted in comments.  
+code and comments contained within the specification; exceptions to this are noted in comments.  
 	The user is encouraged to modify and execute these code examples.
 
 
 
 <h2>Related Documentation</h2>
-
-For overviews, tutorials, examples, guides, and tool documentation, please see:
-<ul>
-  <li>
-	<a href="http://download.boulder.ibm.com/ibmdl/pub/software/dw/specs/ws-sdo/SDO_Specification_Java_V2.01.pdf">SDO Specification</a>
-	</li>	  
-</ul>
+For overviews, tutorials, examples, guides, and tool documentation, please see the
+<a href="http://incubator.apache.org/tuscany/java_sdo_overview.html"> SDO Java Overview
+</a>
+section of the Tuscany website.	  
 
 
 </body>

Added: incubator/tuscany/java/sdo/sdo.xml
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/sdo.xml?view=auto&rev=465232
==============================================================================
--- incubator/tuscany/java/sdo/sdo.xml (added)
+++ incubator/tuscany/java/sdo/sdo.xml Wed Oct 18 05:25:18 2006
@@ -0,0 +1,62 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<!--
+ *  Copyright (c) 2005-2006 The Apache Software Foundation or its licensors, as applicable.
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ -->
+<assembly>
+    <id>bin</id>
+    <includeBaseDirectory>false</includeBaseDirectory>
+    <formats>
+        <format>zip</format>
+        <format>tar.gz</format>
+    </formats>
+
+    <fileSets>
+        <!-- include legal and other files -->
+        <fileSet>
+            <includes>
+                <include>LICENSE.txt</include>
+                <include>NOTICE.txt</include>
+                <include>STATUS.txt</include>
+            </includes>
+        </fileSet>
+        <fileSet>
+            <directory>distribution</directory>
+            <outputDirectory>/</outputDirectory>
+        </fileSet>
+        <fileSet>
+            <directory>target/javadoc/api</directory>
+            <outputDirectory>javadoc/api</outputDirectory>
+        </fileSet>
+        <fileSet>
+            <directory>target/site/apidocs</directory>
+            <outputDirectory>javadoc/impl</outputDirectory>
+        </fileSet>
+    </fileSets>
+
+    <moduleSets>
+        <moduleSet>
+            <includes>
+                <include>org.apache.tuscany.sdo:tuscany-sdo-impl</include>
+                <include>org.apache.tuscany.sdo:tuscany-sdo-tools</include>
+            </includes>
+            <binaries>
+                <outputDirectory>lib</outputDirectory>
+                <unpack>false</unpack>
+                <includeDependencies>true</includeDependencies>
+            </binaries>
+        </moduleSet>
+    </moduleSets>
+</assembly>
+

Modified: incubator/tuscany/java/sdo/tools/pom.xml
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/tools/pom.xml?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/tools/pom.xml (original)
+++ incubator/tuscany/java/sdo/tools/pom.xml Wed Oct 18 05:25:18 2006
@@ -55,4 +55,30 @@
             <artifactId>junit</artifactId>
         </dependency>
     </dependencies>
+
+
+    <build>
+        <plugins>
+            <plugin>
+                <groupId>org.apache.maven.plugins</groupId>
+                <artifactId>maven-javadoc-plugin</artifactId>
+                <configuration>
+                    <!-- <overview>${basedir}/src/main/java/org/apache/tuscany/sdo/overview.html</overview>   -->
+                    <version>2.0</version>
+                </configuration>
+                <!-- <executions>
+                    <execution>
+                        <id>package</id>
+                        <phase>package</phase>
+                        <goals>
+                            <goal>jar</goal>
+                        </goals>
+                    </execution>
+                </executions>  -->
+            </plugin>
+
+        </plugins>
+    </build>
+
+
 </project>

Modified: incubator/tuscany/java/sdo/tools/readme.htm
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/tools/readme.htm?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/tools/readme.htm (original)
+++ incubator/tuscany/java/sdo/tools/readme.htm Wed Oct 18 05:25:18 2006
@@ -1,20 +1,24 @@
                                                                <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
-<html><head><!--  * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- * 
- *   http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.     -->
+<html>
+<head>
+  <!--
+    Licensed to the Apache Software Foundation (ASF) under one
+    or more contributor license agreements.  See the NOTICE file
+    distributed with this work for additional information
+    regarding copyright ownership.  The ASF licenses this file
+    to you under the Apache License, Version 2.0 (the
+    "License"); you may not use this file except in compliance
+    with the License.  You may obtain a copy of the License at
+    
+    http://www.apache.org/licenses/LICENSE-2.0
+    
+    Unless required by applicable law or agreed to in writing,
+    software distributed under the License is distributed on an
+    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+    KIND, either express or implied.  See the License for the
+    specific language governing permissions and limitations
+    under the License.    
+  -->
 
 <meta content="text/html; charset=iso-8859-1" http-equiv="Content-Type">
 <meta content="text/css" http-equiv="Content-Style-Type"><title>Tuscany SDO Tools</title>

Modified: incubator/tuscany/java/sdo/tools/src/test/resources/enum.xsd
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/tools/src/test/resources/enum.xsd?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/tools/src/test/resources/enum.xsd (original)
+++ incubator/tuscany/java/sdo/tools/src/test/resources/enum.xsd Wed Oct 18 05:25:18 2006
@@ -1,21 +1,21 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <!--
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- * 
- *   http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.    
+    Licensed to the Apache Software Foundation (ASF) under one
+    or more contributor license agreements.  See the NOTICE file
+    distributed with this work for additional information
+    regarding copyright ownership.  The ASF licenses this file
+    to you under the Apache License, Version 2.0 (the
+    "License"); you may not use this file except in compliance
+    with the License.  You may obtain a copy of the License at
+    
+    http://www.apache.org/licenses/LICENSE-2.0
+    
+    Unless required by applicable law or agreed to in writing,
+    software distributed under the License is distributed on an
+    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+    KIND, either express or implied.  See the License for the
+    specific language governing permissions and limitations
+    under the License.    
  -->
 <xsd:schema 
   targetNamespace="http://www.example.com/simple"

Modified: incubator/tuscany/java/sdo/tools/src/test/resources/repeatingChoice.xsd
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/tools/src/test/resources/repeatingChoice.xsd?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/tools/src/test/resources/repeatingChoice.xsd (original)
+++ incubator/tuscany/java/sdo/tools/src/test/resources/repeatingChoice.xsd Wed Oct 18 05:25:18 2006
@@ -1,22 +1,23 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <!--
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- * 
- *   http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.    
+    Licensed to the Apache Software Foundation (ASF) under one
+    or more contributor license agreements.  See the NOTICE file
+    distributed with this work for additional information
+    regarding copyright ownership.  The ASF licenses this file
+    to you under the Apache License, Version 2.0 (the
+    "License"); you may not use this file except in compliance
+    with the License.  You may obtain a copy of the License at
+    
+    http://www.apache.org/licenses/LICENSE-2.0
+    
+    Unless required by applicable law or agreed to in writing,
+    software distributed under the License is distributed on an
+    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+    KIND, either express or implied.  See the License for the
+    specific language governing permissions and limitations
+    under the License.    
  -->
+
 <xsd:schema xmlns:repchoice="http://www.example.com/repchoice" xmlns:xsd="http://www.w3.org/2001/XMLSchema" targetNamespace="http://www.example.com/repchoice"> 
   
    <xsd:element name="rc" type="repchoice:RCType"/>

Modified: incubator/tuscany/java/sdo/tools/src/test/resources/sequences.xsd
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/tools/src/test/resources/sequences.xsd?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/tools/src/test/resources/sequences.xsd (original)
+++ incubator/tuscany/java/sdo/tools/src/test/resources/sequences.xsd Wed Oct 18 05:25:18 2006
@@ -1,21 +1,21 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <!--
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- * 
- *   http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.    
+    Licensed to the Apache Software Foundation (ASF) under one
+    or more contributor license agreements.  See the NOTICE file
+    distributed with this work for additional information
+    regarding copyright ownership.  The ASF licenses this file
+    to you under the Apache License, Version 2.0 (the
+    "License"); you may not use this file except in compliance
+    with the License.  You may obtain a copy of the License at
+    
+    http://www.apache.org/licenses/LICENSE-2.0
+    
+    Unless required by applicable law or agreed to in writing,
+    software distributed under the License is distributed on an
+    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+    KIND, either express or implied.  See the License for the
+    specific language governing permissions and limitations
+    under the License.    
  -->
 <xsd:schema xmlns:seq="http://www.example.com/sequences"
 	xmlns:xsd="http://www.w3.org/2001/XMLSchema"

Modified: incubator/tuscany/java/sdo/tools/src/test/resources/simple.xsd
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/tools/src/test/resources/simple.xsd?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/tools/src/test/resources/simple.xsd (original)
+++ incubator/tuscany/java/sdo/tools/src/test/resources/simple.xsd Wed Oct 18 05:25:18 2006
@@ -1,21 +1,21 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <!--
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- * 
- *   http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.    
+    Licensed to the Apache Software Foundation (ASF) under one
+    or more contributor license agreements.  See the NOTICE file
+    distributed with this work for additional information
+    regarding copyright ownership.  The ASF licenses this file
+    to you under the Apache License, Version 2.0 (the
+    "License"); you may not use this file except in compliance
+    with the License.  You may obtain a copy of the License at
+    
+    http://www.apache.org/licenses/LICENSE-2.0
+    
+    Unless required by applicable law or agreed to in writing,
+    software distributed under the License is distributed on an
+    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+    KIND, either express or implied.  See the License for the
+    specific language governing permissions and limitations
+    under the License.    
  -->
 <xsd:schema 
   targetNamespace="http://www.example.com/simple"

Added: incubator/tuscany/java/spec/sdo-api/STATUS.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/spec/sdo-api/STATUS.txt?view=auto&rev=465232
==============================================================================
--- incubator/tuscany/java/spec/sdo-api/STATUS.txt (added)
+++ incubator/tuscany/java/spec/sdo-api/STATUS.txt Wed Oct 18 05:25:18 2006
@@ -0,0 +1,73 @@
+Apache Tuscany Status
+
+Tuscany provides multiple language implementations of the Service Component Architecture (SCA) specifications and related technologies such as SDO.
+
+PROJECT STATUS
+==============
+
+  Tuscany is being incubated at the request of the Apache Web Services PMC.
+  For information on incubation please visit the project page at
+  http://incubator.apache.org/projects/tuscany.html
+
+PENDING ISSUES
+==============
+XXXX-XX-XX CCLA received for IBM's contribution of a C++ implementation
+XXXX-XX-XX CCLA received for BEA and IBM joint contribution of a Java implementation
+
+RESOLVED ISSUES SINCE LAST STATUS
+=================================
+None
+
+OTHER NEWS
+==========
+
+2006-09-29 Vote to add Ignacio Silva-Lepe as a new committer
+2006-09-18 Vote to add Venkata Krishnan as a new committer
+2006-08-10 Vote to add Andrew Borley as a new committer
+2006-08-07 Vote to add Meeraj Kunnumpurath as a new committer
+2006-08-07 Vote to add Kelvin Goodson as a new committer
+2006-08-06 Vote to add Brent Daniel as a new committer
+2006-08-04 Vote to add Raymond Feng as a new committer
+2006-08-01 C++ Milestone 1 release
+2006-06-07 Java Milestone 1 release
+2006-05-02 Vote to add Dan Kulp as a new committer
+
+2006-01-05 Contribution of Java implementation by BEA and IBM committed
+2006-01-05 Contribution of C+ implementation by IBM committed
+
+RELEASE STATUS
+==============
+None
+
+REFERENCES
+==========
+Status file     http://svn.apache.org/repos/asf/incubator/tuscany/STATUS
+User List       tuscany-user@ws.apache.org
+Developer List  tuscany-dev@ws.apache.org
+Commits List    tuscany-commits@ws.apache.org
+Source Code     http://svn.apache.org/repos/asf/incubator/tuscany/
+Issue Tracking  http://issues.apache.org/jira/browse/TUSCANY
+
+Committers
+    ajborley        Andrew Borley
+    antelder        Ant Elder
+    bdaniel         Brent Daniel
+    dkulp           Dan Kulp
+    dims            Davanum Srinivas
+    edslattery      Ed Slattery
+    ekoneil         Eddie O'Neil
+    frankb          Frank Budinsky
+    geirm           Geir Magnusson Jr
+    isilval         Ignacio Silva-Lepe
+    jsdelfino       Jean-Sebastien Delfino
+    jboynes         Jeremy Boynes
+    jmarino         Jim Marino
+    kelvingoodson   Kelvin Goodson
+    kentam          Ken Tam
+    kwilliams       Kevin Williams
+    edwardsmj       Mike Edwards
+    meerajk         Meeraj Kunnumpurath
+    rfeng           Raymond Feng
+    robbinspg       Pete Robbins
+    rineholt        Rick Rineholt
+    svkrish         Venkata Krishnan

Modified: incubator/tuscany/java/spec/sdo-api/pom.xml
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/spec/sdo-api/pom.xml?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/spec/sdo-api/pom.xml (original)
+++ incubator/tuscany/java/spec/sdo-api/pom.xml Wed Oct 18 05:25:18 2006
@@ -95,6 +95,23 @@
                     </osgiManifest>
                 </configuration>
             </plugin>
+            <plugin>
+                <groupId>org.apache.maven.plugins</groupId>
+                <artifactId>maven-javadoc-plugin</artifactId>
+                <configuration>
+                    <overview>${basedir}/src/main/java/commonj/sdo/overview.html</overview> 
+                    <version>2.0</version>
+                </configuration>
+                <executions>
+                    <execution>
+                        <id>package</id>
+                        <phase>package</phase>
+                        <goals>
+                            <goal>jar</goal>
+                        </goals>
+                    </execution>
+                </executions>
+            </plugin>
         </plugins>
         <defaultGoal>install</defaultGoal>
     </build>

Added: incubator/tuscany/java/spec/sdo-api/src/main/java/commonj/sdo/overview.html
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/spec/sdo-api/src/main/java/commonj/sdo/overview.html?view=auto&rev=465232
==============================================================================
--- incubator/tuscany/java/spec/sdo-api/src/main/java/commonj/sdo/overview.html (added)
+++ incubator/tuscany/java/spec/sdo-api/src/main/java/commonj/sdo/overview.html Wed Oct 18 05:25:18 2006
@@ -0,0 +1,10 @@
+<html>
+<head>
+	<title>SDO API Overview</title>
+</head>
+<BODY>
+<h1>Service Data Object (SDO) Application Programmer Interface</h1>  
+<p>
+</P>
+</BODY>
+</html>



---------------------------------------------------------------------
To unsubscribe, e-mail: tuscany-commits-unsubscribe@ws.apache.org
For additional commands, e-mail: tuscany-commits-help@ws.apache.org
--- incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/otherSources/ReadPurchaseOrder.java (original)
+++ incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/otherSources/ReadPurchaseOrder.java Wed Oct 18 05:25:18 2006
@@ -32,7 +32,7 @@
 import org.apache.tuscany.samples.sdo.SdoSampleConstants;
 
 /**
  * Reads purchase order DataObject from XML, based upon Fuhwei Lo's paper <A
  * HREF="http://www-128.ibm.com/developerworks/webservices/library/ws-sdoxmlschema/"
  * title="Me" onClick="checkLinks(this)">Create and read an XML document based on XML
  * Schema</A>.  Uses file
@@ -93,7 +93,7 @@
         System.out.println("***************************************");
         System.out.println("SDO Sample ReadPurchaseOrder");
         System.out.println("***************************************");
-        System.out.println("This sample is based upon Fuhwei Lo's paper http://www-128.ibm.com/developerworks/webservices/library/ws-sdoxmlschema/");
+        System.out.println("This sample is based upon Fuhwei Lwo's paper http://www-128.ibm.com/developerworks/webservices/library/ws-sdoxmlschema/");
         System.out.println("previously generated by CreatePurchaseOrder sample to populate purchase order DataObject");
 
         System.out.println("***************************************");
@@ -32,7 +32,7 @@
 
 /**
- * Reads purchase order DataObject from XML, based upon Fuhwei Lo's paper <A
+ * Reads purchase order DataObject from XML, based upon Fuhwei Lwo's paper <A
  * HREF="http://www-128.ibm.com/developerworks/webservices/library/ws-sdoxmlschema/"
  * title="Me" onClick="checkLinks(this)">Create and read an XML document based on XML

Modified: incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/otherSources/package.html
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/otherSources/package.html?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================